<TS version="2.1" language="zh_HK">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">按右擊修改位址或標記</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>新增一個位址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">新增 &amp;N</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>複製目前選擇的位址到系統剪貼簿</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">複製 &amp;C</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">關閉 &amp;l</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>把目前選擇的位址從列表中刪除</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">輸入位址或標記以作搜尋</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>把目前分頁的資料匯出至檔案</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>匯出 &amp;E</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>刪除 &amp;D</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">選擇要付錢過去的地址</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">選擇要收錢的地址</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">選擇 &amp;h</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">付款地址</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">收款地址</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">這些是你要付款過去的 Bitcoin 位址。在付款之前，務必要檢查金額和收款位址是否正確。</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">複製地址 &amp;C</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">複製標記 &amp;L</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">編輯 &amp;E</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">匯出地址清單</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">儲存地址列表到 %1 時發生錯誤。請再試一次。</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">匯出失敗</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">標記</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">地址</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(無標記)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>複雜密碼對話方塊</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>新密碼</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>重複新密碼</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">顯示密碼</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">加密錢包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">這個動作需要你的錢包密碼來將錢包解鎖。</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">解鎖錢包</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">更改密碼</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">確認錢包加密</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">警告: 如果你將錢包加密後又忘記密碼，你就會&lt;b&gt;失去所有 Bitcoin 了&lt;/b&gt;！</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">你確定要把錢包加密嗎？</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">錢包已加密</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">輸入錢包的新密碼。&lt;br/&gt;密碼請用&lt;b&gt;10 個或以上的隨機字元&lt;/b&gt;，或是&lt;b&gt;8 個或以上的字詞&lt;/b&gt;。</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">請輸入舊密碼和新密碼至錢包。</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">請記得將錢包加密不能完全防止你的 Bitcoins 經被入侵電腦的惡意程式偷取。</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">需要加密的錢包</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">您的錢包將被加密</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">您的錢包剛剛完成加密</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">重要: 請改用新產生的加密錢包檔，來取代所以舊錢包檔的備份。為安全計，當你開始使用新的加密錢包檔後，舊錢包檔的備份就不能再使用了。</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">錢包加密失敗</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">因內部錯誤導致錢包加密失敗，你的錢包尚未加密。</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">提供的密碼不一致。</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">錢包解鎖失敗</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">用來解密錢包的密碼不對。</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">錢包密碼已成功更改。</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">警告: Caps Lock 已啟用！</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP位址/遮罩</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">封鎖至</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">內部錯誤</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">錯誤: %1</translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation type="unfinished">輸入一個 Bitcoin 位址 (例如 %1)</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation type="unfinished">%1 日</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation type="unfinished">%1 小時</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation type="unfinished">%1 分</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation type="unfinished">%1 秒</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished">沒有</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation type="unfinished">%1 亳秒</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 和 %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation>總覽 &amp;O</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>顯示錢包一般總覽</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>交易 &amp;T</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>瀏覽交易紀錄</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>結束 &amp;x</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>結束應用程式</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">關於 %1 &amp;A</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">顯示 %1 的相關資訊</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>關於 Qt &amp;Q</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>顯示 Qt 相關資訊</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">修正 %1 的設定選項</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">新增一個錢包</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">錢包:</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>付款至一個 Bitcoin 位址</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>把錢包備份到其它地方</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>改變錢包加密用的密碼</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>付款 &amp;S</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>收款 &amp;R</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>顯示 / 隱藏 &amp;S</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>顯示或隱藏主視窗</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>檔案 &amp;F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定 &amp;S</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>說明 &amp;H</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">要求付款 (產生QR碼 bitcoin: URIs)</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>資訊</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>已更新至最新版本</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">開啟錢包</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">開啟一個錢包</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">預設錢包</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">主視窗</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">錯誤: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">日期: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">錢包: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">已確認</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(無標記)</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">預設錢包</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">錢包</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">錯誤</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Sent</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have sent to the peer.</extracomment>
        <translation type="unfinished">已送出</translation>
    </message>
    <message>
        <source>Received</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have received from the peer.</extracomment>
        <translation type="unfinished">已接收</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">地址</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>Save QR Code</source>
        <translation type="unfinished">儲存 QR 碼</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>資訊 &amp;I</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">一般</translation>
    </message>
    <message>
        <source>Received</source>
        <translation type="unfinished">已接收</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished">已送出</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">版本</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">錢包:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">標記</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(無標記)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(無標記)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation type="unfinished">開放至 %1</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">標記</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation type="unfinished">開放至 %1</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(無標記)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">已確認</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">標記</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">地址</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">匯出失敗</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">新增一個錢包</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">預設錢包</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">匯出 &amp;E</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">把目前分頁的資料匯出至檔案</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">錯誤</translation>
    </message>
    </context>
</TS>